import { Construct } from "@aws-cdk/core";
/**
 * Organizations offers policy types in the following two broad categories: <ol>      <li>Authorization policies help you to centrally manage the security of the AWS accounts in your organization.</li>      <li>Management policies enable you to centrally configure and manage AWS services and their features.</li> </ol>.
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies.html#orgs-policy-types
 * @stability stable
 */
export declare enum PolicyType {
    /**
     * Service control policies (SCPs) offer central control over the maximum available permissions for all of the accounts in your organization.
     *
     * @stability stable
     */
    SERVICE_CONTROL_POLICY = "SERVICE_CONTROL_POLICY",
    /**
     * Tag policies help you standardize the tags attached to the AWS resources in your organization's accounts.
     *
     * @stability stable
     */
    TAG_POLICY = "TAG_POLICY",
    /**
     * Backup policies help you centrally manage and apply backup plans to the AWS resources across your organization's accounts.
     *
     * @stability stable
     */
    BACKUP_POLICY = "BACKUP_POLICY",
    /**
     * Artificial Intelligence (AI) services opt-out policies enable you to control data collection for AWS AI services for all of your organization's accounts.
     *
     * @stability stable
     */
    AISERVICES_OPT_OUT_POLICY = "AISERVICES_OPT_OUT_POLICY"
}
/**
 * @stability stable
 */
export interface PolicyProps {
    /**
     * The policy text content to add to the new policy.
     *
     * The text that you supply must adhere to the rules of the policy type you specify in the Type parameter.
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * An optional description to assign to the policy.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The friendly name to assign to the policy.
     *
     * @stability stable
     */
    readonly policyName: string;
    /**
     * The type of policy to create.
     *
     * You can specify one of the following values:
     *
     * @stability stable
     */
    readonly policyType: PolicyType;
    /**
     * A list of tags that you want to attach to the newly created policy.
     *
     * For each tag in the list, you must specify both a tag key and a value. You can set the value to an empty string, but you can't set it to null.
     *
     * @stability stable
     */
    readonly tags: {
        [key: string]: string;
    };
}
/**
 * Policies in AWS Organizations enable you to apply additional types of management to the AWS accounts in your organization.
 *
 * <strong>You can use policies when all features are enabled in your organization.</strong>
 *
 * @see FeatureSet
 * @stability stable
 */
export declare class Policy extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: PolicyProps);
}
